@@ -14,18 +14,19 @@ class FaceCollector:
                  inp,
                  save_path: str,
                  op,
-                 mask=True):
+                 mask=True,
+                 pad=128):
         if isinstance(inp, str):
             inp = cv2.imread(inp)
         self.inp = inp
         self.save_path = save_path
         self.mask = mask
+        self.pad = pad
         assert hasattr(op, "__call__"), AssertionError("op不可调用，请检查传入的op是否支持op()操作")
         self.op = op
 
-    @staticmethod
-    def pretreatment(frame):
-        clip, box, seg = get_face(frame)
+    def pretreatment(self, frame):
+        clip, box, seg = get_face(frame, self.mask, self.pad)
         cr = Collector(frame, clip, box, seg)
         return cr
 
