@@ -34,13 +34,17 @@ def face_seg(img, pad=32):
     return result.astype("uint8")
 
 
-def get_face(ori_img, mask=True):
+def get_face(ori_img, mask=True, pad=64):
     img = ori_img.copy()
     # 获取面部分割
     c_mask = face_seg(img)
     img[np.array([c_mask] * img.shape[-1], dtype="uint8").transpose([1, 2, 0]) == 0] = 0
     # 获取外接正矩形
     left, right, top, bottom = face_det(c_mask)
+    left += pad
+    right += pad
+    top += pad
+    bottom += pad
     # 裁剪
     if mask:
         clip = img[top:bottom, left:right, :]
